import { Fragment, lazy } from "react";

const ProductExamsList = lazy(() =>
  import("../productRenderer/ProductExamsList")
);
const ProductFaq = lazy(() => import("../productRenderer/ProductFaq"));
const ProductFilesDownloadBox = lazy(() =>
  import("../productRenderer/ProductFilesDownloadBox")
);
const ProductInternalContent = lazy(() =>
  import("../productRenderer/ProductInternalContent")
);
const ProductIntro = lazy(() => import("../productRenderer/ProductIntro"));
const ProductMenu = lazy(() => import("../productRenderer/ProductMenu"));
const ProductSimpleImages = lazy(() =>
  import("../productRenderer/ProductSimpleImages")
);
const ProductSimpleQuestion = lazy(() =>
  import("../productRenderer/ProductSimpleQuestion")
);
const ProductTips = lazy(() => import("../productRenderer/ProductTips"));
const SimpleProductBenefits = lazy(() =>
  import("../productRenderer/SimpleProductBenefits")
);
const SimpleProductUserVoices = lazy(() =>
  import("../productRenderer/SimpleProductUserVoices")
);
const UserComments = lazy(() => import("../productRenderer/UserComments"));

const sectionLib = {
  p_desc: ProductIntro,
  product_content: ProductInternalContent,
  down_pro: ProductFilesDownloadBox,
  sim_img: ProductSimpleImages,
  "sim-question": ProductSimpleQuestion,
  product_bennefits: SimpleProductBenefits,
  product_tips: ProductTips,
  use_voi: SimpleProductUserVoices,
  com_pro: UserComments,
  product_faq: ProductFaq,
  pro_exams: ProductExamsList,
};

const ProductMainSection = ({ product }) => {
  // console.log(product);
  if (!product.sections) return null;
  return (
    <div className="flex flex-1 flex-col gap-10 lg:gap-12 ">
      <ProductMenu />
      {product.sections.map((section, sectionIndex) => {
        if (section.sectionHeaderData.activeSection) {
          const Component = sectionLib[section.sectionBaseData.type];
          return (
            <Fragment key={sectionIndex}>
              {Component && (
                <Component
                  section={section}
                  exams={
                    section.sectionBaseData.type === "pro_exams"
                      ? product.exams
                      : null
                  }
                />
              )}
            </Fragment>
          );
        } else {
          return null;
        }
      })}
    </div>
  );
};

export default ProductMainSection;
